import { Type } from "igniteui-angular-core";
/**
 * Represents the various ways cells can be referenced in a formula.
 * <p class="body">
 * Setting this on the [[Workbook.cellReferenceMode]] will also affect the row and column labels.
 * </p>
 */
export declare enum CellReferenceMode {
    /**
     * Cells are referenced by first specifying characters representing the column and a one-based number
     * specifying the row (R54 or CA56). The dollar sign ($) can preface one or both identifiers to make them
     * absolute references ($A$7). Without the dollar sign, references still use absolute row and column addresses,
     * although shifting a formula to a new cell will perform a similar shift on all relative references.
     */
    A1 = 1,
    /**
     * Cells are referenced in the following format R<RowIndex>C<ColumnIndex> (R34C5 or R2C345).
     * These indices are one-based and represent absolute references. To create a relative reference in R1C1 mode, a relative
     * index must be placed inside square brackets following the R and/or C ( R[-1]C[5] or R9C[-3] ).  An R by itself
     * also represents a relative reference and is equivalent to R[0]. Similarly, C is equivalent to C[0], which means a
     * formula of =RC always references the cell which contains the formula.
     */
    R1C1 = 0
}
/**
 * @hidden
 */
export declare let CellReferenceMode_$type: Type;
