import { Type } from "igniteui-angular-core";
/**
 * Constants which identify the chart's type, i.e.,
 * area chart, bar chart, pie chart, etc.
 */
export declare enum ChartType {
    /**
     * Not an actual value; used for variable initialization.
     */
    Unknown = 0,
    /**
     * 3D Area.
     */
    Area3D = -4098,
    /**
     * 3D Stacked Area.
     */
    Area3DStacked = 78,
    /**
     * 100% Stacked Area.
     */
    Area3DStacked100 = 79,
    /**
     * 3D Clustered Bar.
     */
    Bar3DClustered = 60,
    /**
     * 3D Stacked Bar.
     */
    Bar3DStacked = 61,
    /**
     * 3D 100% Stacked Bar.
     */
    Bar3DStacked100 = 62,
    /**
     * 3D Column.
     */
    Column3D = -4100,
    /**
     * 3D Clustered Column.
     */
    Column3DClustered = 54,
    /**
     * 3D Stacked Column.
     */
    Column3DStacked = 55,
    /**
     * 3D 100% Stacked Column.
     */
    Column3DStacked100 = 56,
    /**
     * 3D Line.
     */
    Line3D = -4101,
    /**
     * 3D Pie.
     */
    Pie3D = -4102,
    /**
     * Exploded 3D Pie.
     */
    Pie3DExploded = 70,
    /**
     * Area
     */
    Area = 1,
    /**
     * Stacked Area.
     */
    AreaStacked = 76,
    /**
     * 100% Stacked Area.
     */
    AreaStacked100 = 77,
    /**
     * Clustered Bar.
     */
    BarClustered = 57,
    /**
     * Bar of Pie.
     */
    BarOfPie = 71,
    /**
     * Stacked Bar.
     */
    BarStacked = 58,
    /**
     * 100% Stacked Bar.
     */
    BarStacked100 = 59,
    /**
     * Bubble.
     */
    Bubble = 15,
    /**
     * Bubble with 3D effects.
     */
    Bubble3DEffect = 87,
    /**
     * Clustered Column.
     */
    ColumnClustered = 51,
    /**
     * Stacked Column.
     */
    ColumnStacked = 52,
    /**
     * 100% Stacked Column.
     */
    ColumnStacked100 = 53,
    /**
     * Clustered Cone Bar.
     */
    ConeBarClustered = 102,
    /**
     * Stacked Cone Bar.
     */
    ConeBarStacked = 103,
    /**
     * 100% Stacked Cone Bar.
     */
    ConeBarStacked100 = 104,
    /**
     * 3D Cone Column.
     */
    ConeCol = 105,
    /**
     * Clustered Cone Column.
     */
    ConeColClustered = 99,
    /**
     * Stacked Cone Column.
     */
    ConeColStacked = 100,
    /**
     * 100% Stacked Cone Column.
     */
    ConeColStacked100 = 101,
    /**
     * Clustered Cylinder Bar.
     */
    CylinderBarClustered = 95,
    /**
     * Stacked Cylinder Bar.
     */
    CylinderBarStacked = 96,
    /**
     * 100% Stacked Cylinder Bar.
     */
    CylinderBarStacked100 = 97,
    /**
     * 3D Cylinder Column.
     */
    CylinderCol = 98,
    /**
     * Clustered Cone Column.
     */
    CylinderColClustered = 92,
    /**
     * Stacked Cone Column.
     */
    CylinderColStacked = 93,
    /**
     * 100% Stacked Cylinder Column.
     */
    CylinderColStacked100 = 94,
    /**
     * Doughnut.
     */
    Doughnut = -4120,
    /**
     * Exploded Doughnut.
     */
    DoughnutExploded = 80,
    /**
     * Line.
     */
    Line = 4,
    /**
     * Line with Markers.
     */
    LineMarkers = 65,
    /**
     * Stacked Line with Markers.
     */
    LineMarkersStacked = 66,
    /**
     * 100% Stacked Line with Markers.
     */
    LineMarkersStacked100 = 67,
    /**
     * Stacked Line.
     */
    LineStacked = 63,
    /**
     * 100% Stacked Line.
     */
    LineStacked100 = 64,
    /**
     * Pie.
     */
    Pie = 5,
    /**
     * Exploded Pie.
     */
    PieExploded = 69,
    /**
     * Pie of Pie.
     */
    PieOfPie = 68,
    /**
     * Clustered Pyramid Bar.
     */
    PyramidBarClustered = 109,
    /**
     * Stacked Pyramid Bar.
     */
    PyramidBarStacked = 110,
    /**
     * 100% Stacked Pyramid Bar.
     */
    PyramidBarStacked100 = 111,
    /**
     * 3D Pyramid Column.
     */
    PyramidCol = 112,
    /**
     * Clustered Pyramid Column.
     */
    PyramidColClustered = 106,
    /**
     * Stacked Pyramid Column.
     */
    PyramidColStacked = 107,
    /**
     * 100% Stacked Pyramid Column.
     */
    PyramidColStacked100 = 108,
    /**
     * Radar.
     */
    Radar = -4151,
    /**
     * Filled Radar.
     */
    RadarFilled = 82,
    /**
     * Radar with Data Markers.
     */
    RadarMarkers = 81,
    /**
     * High-Low-Close.
     */
    StockHLC = 88,
    /**
     * Open-High-Low-Close.
     */
    StockOHLC = 89,
    /**
     * Volume-High-Low-Close.
     */
    StockVHLC = 90,
    /**
     * Volume-Open-High-Low-Close.
     */
    StockVOHLC = 91,
    /**
     * Surface (a.k.a. Contour).
     */
    Surface = 83,
    /**
     * 3D Surface (Top View).
     */
    SurfaceTopView = 85,
    /**
     * 3D Surface (Top View wireframe).
     */
    SurfaceTopViewWireframe = 86,
    /**
     * Surface (a.k.a. Contour - wireframe).
     */
    SurfaceWireframe = 84,
    /**
     * Scatter.
     */
    XYScatter = -4169,
    /**
     * Scatter with Lines.
     */
    XYScatterLines = 74,
    /**
     * Scatter with Lines and No Data Markers.
     */
    XYScatterLinesNoMarkers = 75,
    /**
     * Scatter with Smoothed Lines.
     */
    XYScatterSmooth = 72,
    /**
     * Scatter with Smoothed Lines and No Data Markers.
     */
    XYScatterSmoothNoMarkers = 73,
    /**
     * Combination of different chart types.
     */
    Combo = 113,
    /**
     * Box and whisker (Office2016 or later)
     */
    BoxAndWhisker = 114,
    /**
     * Funnel (Office365 only)
     */
    Funnel = 115,
    /**
     * Pareto chart with bars and lines (Office2016 or later)
     */
    Pareto = 116,
    /**
     * Histogram chart (Office2016 or later)
     */
    Histogram = 117,
    /**
     * Sunburst chart (Office2016 or later)
     */
    Sunburst = 118,
    /**
     * Tree map chart (Office2016 or later)
     */
    Treemap = 119,
    /**
     * Waterfall chart (Office2016 or later)
     */
    Waterfall = 120,
    /**
     * Region map (geographic) chart (Office365 only)
     */
    RegionMap = 121
}
/**
 * @hidden
 */
export declare let ChartType_$type: Type;
