import { Type } from "igniteui-angular-core";
/**
 * Constants which define the location at which a [[DataLabel]] is positioned.
 * <p class="body">
 * Note that which constants in this enumeration are applicable is dependent on the chart type.
 * </p>
 * <p class="body">
 * The following table lists the supported constants for each chart type.
 * </p>
 * <p class="body">
 * <table border="1">
 * <tr>
 * <th><b>Chart Type</b></th><th><b>Supported Constant(s)</b></th>
 * </tr>
 * <tr>
 * <td>3D charts (except pie/doughnut)</td><td>Custom</td>
 * </tr>
 * <tr>
 * <td>Area, Radar</td><td>Custom</td>
 * </tr>
 * <tr>
 * <td>Surface</td><td>Data labels are not supported</td>
 * </tr>
 * <tr>
 * <td>Bar/Column (stacked)</td><td>Center, InsideEnd, InsideBase</td>
 * </tr>
 * <tr>
 * <td>Bar/Column (clustered)</td><td>Center, InsideEnd, InsideBase, OutsideEnd</td>
 * </tr>
 * <tr>
 * <td>Line/Scatter/Bubble</td><td>Center, Left, Right, Above, Below</td>
 * </tr>
 * <tr>
 * <td>Pie/Doughnut</td><td>Center, InsideEnd, OutsideEnd, BestFit</td>
 * </tr>
 * </table>
 * </p>
 * @see [[DataLabel.labelPosition]]
 * @see [[Series.dataLabels]]
 * @see [[DataLabel]]
 */
export declare enum DataLabelPosition {
    /**
     * The label position is not specified, and is determined automatically by Excel.
     */
    Default = 0,
    /**
     * The label is centered with respect to the associated data point.
     */
    Center = 1,
    /**
     * The label's left edge coincides with the left edge of the series bar/line.
     */
    InsideBase = 2,
    /**
     * The label's right edge coincides with the right edge of the series bar/line.
     */
    InsideEnd = 3,
    /**
     * The label's left edge coincides with the right edge of the series bar/line.
     */
    OutsideEnd = 4,
    /**
     * The label's position is explicitly defined via the [[ChartTextAreaBase.left]]
     * and [[ChartTextAreaBase.top]] properties.
     */
    Custom = 5,
    /**
     * The label is positioned to the left of the associated data point.
     */
    Left = 6,
    /**
     * The label is positioned to the right of the associated data point.
     */
    Right = 7,
    /**
     * The label is positioned above the associated data point.
     */
    Above = 8,
    /**
     * The label is positioned below the associated data point.
     */
    Below = 9,
    /**
     * The label is positioned where it best fits with relation to the associated pie slice.
     */
    BestFit = 10
}
/**
 * @hidden
 */
export declare let DataLabelPosition_$type: Type;
