import { Type } from "igniteui-angular-core";
/**
 * Represents the various styles in which invalid values are handled by Microsoft Excel. When error messages are not
 * shown for invalid values, the error style is ignored and all invalid values are allowed to be set on cells.
 * @see [[DataValidationRule.errorStyle]]
 * @see [[DataValidationRule.showErrorMessageForInvalidValue]]
 */
export declare enum DataValidationErrorStyle {
    /**
     * Invalid values are not allowed. The error dialog shown in Microsoft Excel displays an error icon and retry and cancel
     * buttons. The retry button will put focus back in the cell and allow the user to try to enter a new value. The cancel
     * button will cancel the edit and revert the cell back to the previous value it contained before the edit operation.
     */
    Stop = 0,
    /**
     * Invalid values are allowed. The error dialog shown in Microsoft Excel displays a warning icon, asks the user if they
     * want to continue, and has yes, no and cancel buttons. The yes button commits the value to the cell. The no button will
     * put focus back in the cell and allow the user to try to enter a new value. And the cancel button will cancel the edit
     * and revert the cell back to the previous value it contained before the edit operation.
     */
    Warning = 1,
    /**
     * Invalid values are allowed. The error dialog shown in Microsoft Excel displays an information icon and ok and cancel
     * buttons. The ok button commits the value to the cell. The cancel button will cancel the edit and revert the cell back
     * to the previous value it contained before the edit operation.
     */
    Information = 2
}
/**
 * @hidden
 */
export declare let DataValidationErrorStyle_$type: Type;
