import { Type } from "igniteui-angular-core";
/**
 * Constants which determine the unit of expression for
 * [[Axis]] value labels.
 */
export declare enum DisplayUnit {
    /**
     * The raw value is displayed without special formatting.
     */
    None = -4142,
    /**
     * The [[Axis.displayUnitCustom]] property determines the display unit.
     */
    Custom = -4114,
    /**
     * 100,000,000
     */
    HundredMillions = -8,
    /**
     * 100
     */
    Hundreds = -2,
    /**
     * 100,000
     */
    HundredThousands = -5,
    /**
     * 1,000,000,000,000 (trillions)
     */
    MillionMillions = -10,
    /**
     * 1,000,000
     */
    Millions = -6,
    /**
     * 10,000,000
     */
    TenMillions = -7,
    /**
     * 10,000
     */
    TenThousands = -4,
    /**
     * 1,000,000,000 (billions)
     */
    ThousandMillions = -9,
    /**
     * 1,000
     */
    Thousands = -3,
    /**
     * Displays as a percentage. Applicable only to
     * Box and Whisker, Histogram, Pareto, Sunburst, Treemap, and Waterfall chart types;
     * if used for any other chart type, resolved to <i>Hundreds</i>.
     */
    Percentage = 1
}
/**
 * @hidden
 */
export declare let DisplayUnit_$type: Type;
