import { Type } from "igniteui-angular-core";
/**
 * Constants which identify the type of value which defines the criteria for a
 * [[ColorScaleCriterion]] or [[IconCriterion]].
 */
export declare enum FormatConditionValueType {
    /**
     * The criteria is defined by a numeric value.
     */
    Number = 0,
    /**
     * The criteria is defined by a percentage.
     */
    Percentage = 1,
    /**
     * The criteria is defined by a percentile rating.
     */
    Percentile = 2,
    /**
     * The criteria is defined by a formula.
     */
    Formula = 3,
    /**
     * The criteria is defined by the lowest value across the associated range.
     */
    LowestValue = 4,
    /**
     * The criteria is defined by the highest value across the associated range.
     */
    HighestValue = 5,
    /**
     * The shortest data bar is proportional to the lowest value across the associated range.
     * Applicable only to the [[IconCriterion]] class.
     */
    AutomaticMinimum = 6,
    /**
     * The longest data bar is proportional to the highest value across the associated range.
     * Applicable only to the [[IconCriterion]] class.
     */
    AutomaticMaximum = 7
}
/**
 * @hidden
 */
export declare let FormatConditionValueType_$type: Type;
