import { Type } from "igniteui-angular-core";
/**
 * Constants which determine the placement of the chart's
 * [[Legend]].
 */
export declare enum LegendPosition {
    /**
     * The legend appears at the bottom of the chart.
     */
    Bottom = 0,
    /**
     * The legend appears near the left edge of the chart.
     */
    Left = 1,
    /**
     * The legend appears near the right edge of the chart.
     */
    Right = 2,
    /**
     * The legend appears at the top of the chart.
     */
    Top = 3,
    /**
     * The legend appears near the top right corner of the chart.
     */
    TopRight = 4,
    /**
     * The legend's size and location is determined by the
     * [[Legend.left]], [[Legend.top]],
     * [[Legend.width]], and [[Legend.height]]
     * properties.
     */
    Custom = 5,
    /**
     * The legend position is determined automatically by Excel.
     */
    Default = 6,
    /**
     * The legend appears near the top left corner of the chart.
     * Supported only for Histogram, Pareto, Treemap, Sunburst, Box and Whisker, and Waterfall chart types.
     */
    TopLeft = 7,
    /**
     * The legend appears near the bottom left corner of the chart.
     * Supported only for Histogram, Pareto, Treemap, Sunburst, Box and Whisker, and Waterfall chart types.
     */
    BottomLeft = 8,
    /**
     * The legend appears near the bottom right corner of the chart.
     * Supported only for Histogram, Pareto, Treemap, Sunburst, Box and Whisker, and Waterfall chart types.
     */
    BottomRight = 9
}
/**
 * @hidden
 */
export declare let LegendPosition_$type: Type;
