import { Type } from "igniteui-angular-core";
/**
 * Represents the various paper sizes available for printing.
 */
export declare enum PaperSize {
    /**
     * Undefined
     */
    Undefined = 0,
    /**
     * Letter 8 1/2\" x 11\"
     */
    Letter = 1,
    /**
     * Letter small 8 1/2\" x 11\"
     */
    LetterSmall = 2,
    /**
     * Tabloid 11\" x 17\"
     */
    Tabloid = 3,
    /**
     * Ledger 17\" x 11\"
     */
    Ledger = 4,
    /**
     * Legal 8 1/2\" x 14\"
     */
    Legal = 5,
    /**
     * Statement 5 1/2\" x 8 1/2\"
     */
    Statement = 6,
    /**
     * Executive 7 1/4\" x 10 1/2\"
     */
    Executive = 7,
    /**
     * A3 297mm x 420mm
     */
    A3 = 8,
    /**
     * A4 210mm x 297mm
     */
    A4 = 9,
    /**
     * A4 small 210mm x 297mm
     */
    A4Small = 10,
    /**
     * A5 148mm x 210mm
     */
    A5 = 11,
    /**
     * B4 (JIS) 257mm x 364mm
     */
    B4JIS = 12,
    /**
     * B5 (JIS) 182mm x 257mm
     */
    B5JIS = 13,
    /**
     * Folio 8 1/2\" x 13\"
     */
    Folio = 14,
    /**
     * Quarto 215mm x 275mm
     */
    Quarto = 15,
    /**
     * 10x14 10\" x 14\"
     */
    Size10x14 = 16,
    /**
     * 11x17 11\" x 17\"
     */
    Size11x17 = 17,
    /**
     * Note 8 1/2\" x 11\"
     */
    Note = 18,
    /**
     * Envelope #9 3 7/8\" x 8 7/8\"
     */
    Envelope9 = 19,
    /**
     * Envelope #10 4 1/8\" x 9 1/2\"
     */
    Envelope10 = 20,
    /**
     * Envelope #11 4 1/2\" x 10 3/8\"
     */
    Envelope11 = 21,
    /**
     * Envelope #12 4 3/4\" x 11\"
     */
    Envelope12 = 22,
    /**
     * Envelope #14 5\" x 11 1/2\"
     */
    Envelope14 = 23,
    /**
     * C 17\" x 22\"
     */
    C = 24,
    /**
     * D 22\" x 34\"
     */
    D = 25,
    /**
     * E 34\" x 44\"
     */
    E = 26,
    /**
     * Envelope DL 110mm x 220mm
     */
    EnvelopeDL = 27,
    /**
     * Envelope C5 162mm x 229mm
     */
    EnvelopeC5 = 28,
    /**
     * Envelope C3 324mm x 458mm
     */
    EnvelopeC3 = 29,
    /**
     * Envelope C4 229mm x 324mm
     */
    EnvelopeC4 = 30,
    /**
     * Envelope C6 114mm x 162mm
     */
    EnvelopeC6 = 31,
    /**
     * Envelope C6/C5 114mm x 229mm
     */
    EnvelopeC6C5 = 32,
    /**
     * B4 (ISO) 250mm x 353mm
     */
    B4ISO_1 = 33,
    /**
     * B5 (ISO) 176mm x 250mm
     */
    B5ISO = 34,
    /**
     * B6 (ISO) 125mm x 176mm
     */
    B6ISO = 35,
    /**
     * Envelope Italy 110mm x 230mm
     */
    EnvelopeItaly = 36,
    /**
     * Envelope Monarch 3 7/8\" x 7 1/2\"
     */
    EnvelopeMonarch = 37,
    /**
     * 6 3/4 Envelope 3 5/8\" x 6 1/2\"
     */
    Size634Envelope = 38,
    /**
     * US Standard Fanfold 14 7/8\" x 11\"
     */
    USStandardFanfold = 39,
    /**
     * German Std. Fanfold 8 1/2\" x 12\"
     */
    GermanStandardFanfold = 40,
    /**
     * German Legal Fanfold 8 1/2\" x 13\"
     */
    GermanLegalFanfold = 41,
    /**
     * B4 (ISO) 250mm x 353mm
     */
    B4ISO_2 = 42,
    /**
     * Japanese Postcard 100mm x 148mm
     */
    JapanesePostcard = 43,
    /**
     * 9x11 9\" x 11\"
     */
    Size9x11 = 44,
    /**
     * 10x11 10\" x 11\"
     */
    Size10x11 = 45,
    /**
     * 15x11 15\" x 11\"
     */
    Size15x11 = 46,
    /**
     * Envelope Invite 220mm x 220mm
     */
    EnvelopeInvite = 47,
    /**
     * Letter Extra 9 1/2\" x 12\"
     */
    LetterExtra = 50,
    /**
     * Legal Extra 9 1/2\" x 15\"
     */
    LegalExtra = 51,
    /**
     * Tabloid Extra 11 11/16\" x 18\"
     */
    TabloidExtra = 52,
    /**
     * A4 Extra 235mm x 322mm
     */
    A4Extra = 53,
    /**
     * Letter Transverse 8 1/2\" x 11\"
     */
    LetterTransverse = 54,
    /**
     * A4 Transverse 210mm x 297mm
     */
    A4Transverse = 55,
    /**
     * Letter Extra Transv. 9 1/2\" x 12\"
     */
    LetterExtraTransverse = 56,
    /**
     * Super A/A4 227mm x 356mm
     */
    SuperAA4 = 57,
    /**
     * Super B/A3 305mm x 487mm
     */
    SuperBA3 = 58,
    /**
     * Letter Plus 8 1/2\" x 12 11/16\"
     */
    LetterPlus = 59,
    /**
     * A4 Plus 210mm x 330mm
     */
    A4Plus = 60,
    /**
     * A5 Transverse 148mm x 210mm
     */
    A5Transverse = 61,
    /**
     * B5 (JIS) Transverse 182mm x 257mm
     */
    B5JISTransverse = 62,
    /**
     * A3 Extra 322mm x 445mm
     */
    A3Extra = 63,
    /**
     * A5 Extra 174mm x 235mm
     */
    A5Extra = 64,
    /**
     * B5 (ISO) Extra 201mm x 276mm
     */
    B5ISOExtra = 65,
    /**
     * A2 420mm x 594mm
     */
    A2 = 66,
    /**
     * A3 Transverse 297mm x 420mm
     */
    A3Transverse = 67,
    /**
     * A3 Extra Transverse 322mm x 445mm
     */
    A3ExtraTransverse = 68,
    /**
     * Dbl. Japanese Postcard 200mm x 148mm
     */
    DblJapanesePostcard = 69,
    /**
     * A6 105mm x 148mm
     */
    A6 = 70,
    /**
     * Letter Rotated 11\" x 8 1/2\"
     */
    LetterRotated = 75,
    /**
     * A3 Rotated 420mm x 297mm
     */
    A3Rotated = 76,
    /**
     * A4 Rotated 297mm x 210mm
     */
    A4Rotated = 77,
    /**
     * A5 Rotated 210mm x 148mm
     */
    A5Rotated = 78,
    /**
     * B4 (JIS) Rotated 364mm x 257mm
     */
    B4JISRotated = 79,
    /**
     * B5 (JIS) Rotated 257mm x 182mm
     */
    B5JISRotated = 80,
    /**
     * Japanese Postcard Rot. 148mm x 100mm
     */
    JapanesePostcardRotated = 81,
    /**
     * Dbl. Jap. Postcard Rot. 148mm x 200mm
     */
    DblJapanesePostcardRotated = 82,
    /**
     * A6 Rotated 148mm x 105mm
     */
    A6Rotated = 83,
    /**
     * B6 (JIS) 128mm x 182mm
     */
    B6JIS = 88,
    /**
     * B6 (JIS) Rotated 182mm x 128mm
     */
    B6JISRotated = 89,
    /**
     * 12x11 12\" x 11\"
     */
    Size12x11 = 90
}
/**
 * @hidden
 */
export declare let PaperSize_$type: Type;
