import { Type } from "igniteui-angular-core";
/**
 * Determines the direction in which text flows.
 */
export declare enum TextDirection {
    /**
     * Text flows along the horizontal plane. Note that under this setting,
     * text rotation is also supported, with the angle of rotation being
     * relative to the horizontal plane.
     */
    Horizontal = 0,
    /**
     * Text flows along the vertical plane. The plane is defined by rotating
     * the horizontal axis by 90 degrees in the clockwise direction.
     */
    Vertical = 1,
    /**
     * Text flows along the vertical plane. The plane is defined by rotating
     * the horizontal axis by 270 degrees in the clockwise direction.
     */
    Vertical270 = 2,
    /**
     * Text flows along the vertical plane with East Asian vertical orientation.
     */
    EastAsianVertical = 3,
    /**
     * Text flows along the vertical plane with Mongolian vertical orientation.
     */
    MongolianVertical = 4,
    /**
     * Text flows along the vertical plane with WordArt vertical orientation.
     */
    WordArtVertical = 5,
    /**
     * Similar to <i>WordArtVertical</i>, with a right-to-left text reading direction.
     */
    WordArtVerticalRtl = 6
}
/**
 * @hidden
 */
export declare let TextDirection_$type: Type;
