import { Type } from "igniteui-angular-core";
/**
 * Flagged enumeration which indicates which groups of formatting properties are used in a format.
 * @see [[IWorksheetCellFormat.formatOptions]]
 */
export declare enum WorksheetCellFormatOptions {
    /**
     * No format properties are used on the format.
     */
    None = 0,
    /**
     * The [[IWorksheetCellFormat.formatString]] property is used on the format.
     */
    ApplyNumberFormatting = 1,
    /**
     * The [[IWorksheetCellFormat.alignment]], [[IWorksheetCellFormat.indent]], [[IWorksheetCellFormat.rotation]],
     * [[IWorksheetCellFormat.shrinkToFit]], [[IWorksheetCellFormat.verticalAlignment]], and
     * [[IWorksheetCellFormat.wrapText]] properties are used on the format.
     */
    ApplyAlignmentFormatting = 2,
    /**
     * The [[IWorksheetCellFormat.font]] property is used on the format.
     */
    ApplyFontFormatting = 4,
    /**
     * The [[IWorksheetCellFormat.bottomBorderColorInfo]], [[IWorksheetCellFormat.bottomBorderStyle]],
     * [[IWorksheetCellFormat.diagonalBorderColorInfo]], [[IWorksheetCellFormat.diagonalBorders]],
     * [[IWorksheetCellFormat.diagonalBorderStyle]], [[IWorksheetCellFormat.leftBorderColorInfo]],
     * [[IWorksheetCellFormat.leftBorderStyle]], [[IWorksheetCellFormat.rightBorderColorInfo]],
     * [[IWorksheetCellFormat.rightBorderStyle]], [[IWorksheetCellFormat.topBorderColorInfo]], and
     * [[IWorksheetCellFormat.topBorderStyle]] properties are used on the format.
     */
    ApplyBorderFormatting = 8,
    /**
     * The [[IWorksheetCellFormat.fill]] property is used on the format.
     */
    ApplyFillFormatting = 16,
    /**
     * The [[IWorksheetCellFormat.locked]] property is used on the format.
     */
    ApplyProtectionFormatting = 32,
    /**
     * All properties are used on the format.
     */
    All = 63
}
/**
 * @hidden
 */
export declare let WorksheetCellFormatOptions_$type: Type;
