import { Type } from "igniteui-angular-core";
/**
 * Represents the various areas which can have a format applied at the table level.
 * @see [[WorksheetTable.areaFormats]]
 */
export declare enum WorksheetTableArea {
    /**
     * The format is applied to the entire table. Only the outer border properties can be set on this area format.
     * Setting any other will cause an exception.
     */
    WholeTable = 0,
    /**
     * The format is applied to the data area of the table.
     */
    DataArea = 1,
    /**
     * The format is applied to the header row of the table. All but the top border properties can be set on this
     * area format. Setting the top border properties will cause an exception.
     */
    HeaderRow = 2,
    /**
     * The format is applied to the totals row of the table. All but the bottom border properties can be set on this
     * area format. Setting the bottom border properties will cause an exception.
     */
    TotalsRow = 3
}
/**
 * @hidden
 */
export declare let WorksheetTableArea_$type: Type;
