import { Type } from "igniteui-angular-core";
/**
 * Represents the various areas which can have a format applied at the table style level.
 * <p class="note">
 * <b>Note:</b> Only certain properties can be set on the table style are formats. The are as follows:
 * <list type="bullet">
 * <item>[[IWorksheetCellFormat.bottomBorderColorInfo]]</item>
 * <item>[[IWorksheetCellFormat.bottomBorderStyle]]</item>
 * <item>[[IWorksheetCellFormat.fill]]</item>
 * <item>[[IWorksheetCellFormat.leftBorderColorInfo]]</item>
 * <item>[[IWorksheetCellFormat.leftBorderStyle]]</item>
 * <item>[[IWorksheetCellFormat.rightBorderColorInfo]]</item>
 * <item>[[IWorksheetCellFormat.rightBorderStyle]]</item>
 * <item>[[IWorksheetCellFormat.topBorderColorInfo]]</item>
 * <item>[[IWorksheetCellFormat.topBorderStyle]]</item>
 * <item><see cref="IWorkbookFont.Bold">Font.Bold</see></item>
 * <item><see cref="IWorkbookFont.ColorInfo">Font.ColorInfo</see></item>
 * <item><see cref="IWorkbookFont.Italic">Font.Italic</see></item>
 * <item><see cref="IWorkbookFont.Strikeout">Font.Strikeout</see></item>
 * <item><see cref="IWorkbookFont.UnderlineStyle">Font.UnderlineStyle</see></item>
 * </list>
 * Setting any other format or font properties on the table style areas will cause an exception.
 * </p>
 * @see [[WorksheetTableStyle.areaFormats]]
 */
export declare enum WorksheetTableStyleArea {
    /**
     * The format is applied to the entire table.
     */
    WholeTable = 0,
    /**
     * The format is applied to the odd numbered column stripes in the table.
     */
    ColumnStripe = 7,
    /**
     * The format is applied to the even numbered column stripes in the table.
     */
    AlternateColumnStripe = 8,
    /**
     * The format is applied to the odd numbered row stripes in the table.
     */
    RowStripe = 5,
    /**
     * The format is applied to the even numbered row stripes in the table.
     */
    AlternateRowStripe = 6,
    /**
     * The format is applied to the last column in the table.
     */
    LastColumn = 4,
    /**
     * The format is applied to the first column in the table.
     */
    FirstColumn = 3,
    /**
     * The format is applied to the header row in the table.
     */
    HeaderRow = 1,
    /**
     * The format is applied to the totals row in the table.
     */
    TotalRow = 2,
    /**
     * The format is applied to the first header cell in the table.
     */
    FirstHeaderCell = 9,
    /**
     * The format is applied to the last header cell in the table.
     */
    LastHeaderCell = 10,
    /**
     * The format is applied to the first total cell in the table.
     */
    FirstTotalCell = 11,
    /**
     * The format is applied to the last total cell in the table.
     */
    LastTotalCell = 12
}
/**
 * @hidden
 */
export declare let WorksheetTableStyleArea_$type: Type;
